==> dde-qt-dbus-factory_1.0.5.orig.tar.gz: dde-qt-dbus-factory-1.0.5/CHANGELOG.md <==
<a name="1.0.5"></a>
### 1.0.5 (2018-10-25)


#### Features

*   update com.deepin.dde.launcher xml file ([7f3b82d4](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/7f3b82d48b9a749e786f6d130d55c61afd97be85))
*   update com.deepin.daemon.Grub2 ([a26ff4f2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/a26ff4f27fa021abeb95dfa42d4cd4b59537d111))
*   add Opacity property for appearance ([afe91324](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/afe913241594e4424cbc78f752f627599fba50bd))
* **Logined:**  add LastLogoutUser interface ([e451ca83](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/e451ca83941a3e7d3b8ffc0dea56693c2abe699f))



<a name="1.0.4"></a>
### 1.0.4 (2018-07-31)


#### Features

* **mouse:**  Mouse accel profile support ([dd33458d](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/dd33458d09eec753ff75bb4b4ab0119c8a71ad1c))



<a name="1.0.3"></a>
### 1.0.3 (2018-07-20)


#### Features

* **power:**  update com.deepin.system.SystemPower ([b10175cd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/b10175cd951bec7c32b7d9af97c74bbdc647595d))



<a name="1.0.2"></a>
## 1.0.2 (2018-05-14)


#### Features

* **bluetooth:**  add cancel signal ([59f3965a](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/59f3965afb832a2eec16abcd2bef89cc9ed7b8be))



<a name="1.0.1"></a>
## 1.0.1 (2018-03-14)


#### Bug Fixes

*   restore compatibility interface with Accounts DBus ([5b30fc6e](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/5b30fc6e3f995df6f62fc8dc0fdb7e0e2b0487d2))



<a name="1.0.0"></a>
## 1.0.0 (2018-03-08)


#### Features

*   add com.deepin.dde.daemon.Dock xml file ([285186bd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/285186bdaed7a4e06c9ce7f8544a69c000a8b32f))
*   support cmake config ([cdd46dce](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/cdd46dcebf3c81fa5a3c6049e9c1c8c364fca5b8))
*   ebable no_keyword ([2c31ce25](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/2c31ce258cacec0257136a8d803444247ecea120))
*   add com.deepin.dde.Notification dbus ([ab7fe9fd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/ab7fe9fda29ff4d6e75946068832591e4ca2a16d))
*   add login1 xml ([971ce6c2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/971ce6c20d973a4f69bda5b4cfc03c112b0b3f7b))
*   update wm_switcher to WMSwitcher ([7961d95d](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/7961d95d45185881ac1b0496930e4ffbd6c6f296))
* **InputDevices:**  update xml ([37730222](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/3773022268d3a9a1340a910fa8f7418a38c11eb6))
* **accounts:**  update account user xml ([27abfa61](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/27abfa6140a156c08049f1bd97d563688a0b7b0a))
* **lastore:**  add new xml ([d65bf3f2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/d65bf3f2e31adf3f6d2c619cf35c4aeb1c90108f))
* **rename:**  rename xmousearea to XEventMonitor ([36744c67](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/36744c67e49a2a8de0a70e07f6e5aa80e77e7418))
* **touchpad:**  update xml file ([ff1bc733](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/ff1bc7330053026de03692f14fb85487558bc436))

#### Bug Fixes

*   data not cached when sync ([12be6744](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/12be67446ea2b0dea423da2f391bda6e2bc00498))
*   Adapt lintian ([532ec5e8](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/532ec5e85419ac6b6311d989bab32a801bb86e7b))
* **notify:**  type error ([f97ef552](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/f97ef552b28503bd43dd5ca24d4976754711a61f))



<a name="0.4.2"></a>
### 0.4.2 (2017-11-16)


#### Features

* **appearance:**  update interface ([e9f67210](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/e9f672105b00f94c781a7ade3d5ad950f4908ede))



<a name="0.4.1"></a>
### 0.4.1 (2017-11-09)


#### Features

* **imageblur:**  add imageblur interface ([67c8447a](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/67c8447a6dc91baa38fc6929a8ec29c7c734b0b2))



<a name=""></a>
##  0.4.0 (2017-11-03)


#### Features

* **grub:**  update grub theme xml ([fe24b0f1](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/fe24b0f19eaaca52fffd050366dacb1146d3033e))



<a name=""></a>
##  (2017-10-25)


#### Features

*   qdbusxml2cpp keep property name first upper ([92272979](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/922729797de23653d9b8b57100c9424430235959))
*   appearance add scale ([a2b4ae71](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/a2b4ae71a2738f0ccead99dc7416f2398cf798df))

==> dde-qt-dbus-factory_1.0.6.orig.tar.gz: dde-qt-dbus-factory-1.0.6/CHANGELOG.md <==
<a name="1.0.6"></a>
### 1.0.6 (2018-11-30)


#### Features

*   add com.deepin.lastore.SMartmirror xml file ([97d4fc2f](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/97d4fc2fb6ddaf39571be6811a2aa6472c35b7b5))
*   add com.deepin.appstore.metadata xml file ([dec117d7](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/dec117d7ad457bef412d60e611670147e21b1eec))



<a name="1.0.5"></a>
### 1.0.5 (2018-10-25)


#### Features

*   update com.deepin.dde.launcher xml file ([7f3b82d4](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/7f3b82d48b9a749e786f6d130d55c61afd97be85))
*   update com.deepin.daemon.Grub2 ([a26ff4f2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/a26ff4f27fa021abeb95dfa42d4cd4b59537d111))
*   add Opacity property for appearance ([afe91324](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/afe913241594e4424cbc78f752f627599fba50bd))
* **Logined:**  add LastLogoutUser interface ([e451ca83](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/e451ca83941a3e7d3b8ffc0dea56693c2abe699f))



<a name="1.0.4"></a>
### 1.0.4 (2018-07-31)


#### Features

* **mouse:**  Mouse accel profile support ([dd33458d](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/dd33458d09eec753ff75bb4b4ab0119c8a71ad1c))



<a name="1.0.3"></a>
### 1.0.3 (2018-07-20)


#### Features

* **power:**  update com.deepin.system.SystemPower ([b10175cd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/b10175cd951bec7c32b7d9af97c74bbdc647595d))



<a name="1.0.2"></a>
## 1.0.2 (2018-05-14)


#### Features

* **bluetooth:**  add cancel signal ([59f3965a](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/59f3965afb832a2eec16abcd2bef89cc9ed7b8be))



<a name="1.0.1"></a>
## 1.0.1 (2018-03-14)


#### Bug Fixes

*   restore compatibility interface with Accounts DBus ([5b30fc6e](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/5b30fc6e3f995df6f62fc8dc0fdb7e0e2b0487d2))



<a name="1.0.0"></a>
## 1.0.0 (2018-03-08)


#### Features

*   add com.deepin.dde.daemon.Dock xml file ([285186bd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/285186bdaed7a4e06c9ce7f8544a69c000a8b32f))
*   support cmake config ([cdd46dce](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/cdd46dcebf3c81fa5a3c6049e9c1c8c364fca5b8))
*   ebable no_keyword ([2c31ce25](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/2c31ce258cacec0257136a8d803444247ecea120))
*   add com.deepin.dde.Notification dbus ([ab7fe9fd](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/ab7fe9fda29ff4d6e75946068832591e4ca2a16d))
*   add login1 xml ([971ce6c2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/971ce6c20d973a4f69bda5b4cfc03c112b0b3f7b))
*   update wm_switcher to WMSwitcher ([7961d95d](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/7961d95d45185881ac1b0496930e4ffbd6c6f296))
* **InputDevices:**  update xml ([37730222](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/3773022268d3a9a1340a910fa8f7418a38c11eb6))
* **accounts:**  update account user xml ([27abfa61](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/27abfa6140a156c08049f1bd97d563688a0b7b0a))
* **lastore:**  add new xml ([d65bf3f2](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/d65bf3f2e31adf3f6d2c619cf35c4aeb1c90108f))
* **rename:**  rename xmousearea to XEventMonitor ([36744c67](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/36744c67e49a2a8de0a70e07f6e5aa80e77e7418))
* **touchpad:**  update xml file ([ff1bc733](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/ff1bc7330053026de03692f14fb85487558bc436))

#### Bug Fixes

*   data not cached when sync ([12be6744](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/12be67446ea2b0dea423da2f391bda6e2bc00498))
*   Adapt lintian ([532ec5e8](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/532ec5e85419ac6b6311d989bab32a801bb86e7b))
* **notify:**  type error ([f97ef552](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/f97ef552b28503bd43dd5ca24d4976754711a61f))



<a name="0.4.2"></a>
### 0.4.2 (2017-11-16)


#### Features

* **appearance:**  update interface ([e9f67210](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/e9f672105b00f94c781a7ade3d5ad950f4908ede))



<a name="0.4.1"></a>
### 0.4.1 (2017-11-09)


#### Features

* **imageblur:**  add imageblur interface ([67c8447a](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/67c8447a6dc91baa38fc6929a8ec29c7c734b0b2))



<a name=""></a>
##  0.4.0 (2017-11-03)


#### Features

* **grub:**  update grub theme xml ([fe24b0f1](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/fe24b0f19eaaca52fffd050366dacb1146d3033e))



<a name=""></a>
##  (2017-10-25)


#### Features

*   qdbusxml2cpp keep property name first upper ([92272979](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/922729797de23653d9b8b57100c9424430235959))
*   appearance add scale ([a2b4ae71](https://github.com/linuxdeepin/dde-qt-dbus-factory/commit/a2b4ae71a2738f0ccead99dc7416f2398cf798df))
